@@ -42,7 +42,6 @@ llm = init_chat_model("openai:gpt-4.1-nano")
 
 run_chatbot = False
 
-
 def chatbot(state: State):
     return {"messages": [llm.invoke(state["messages"])]}
 
@@ -143,7 +142,7 @@ async def answer_agent_question(question: str, title: str, category: str, busine
         return f"Error generating email: {str(e)}"
 
 
-async def generate_mail(row, row_number: int = 0) -> str:
+async def generate_mail(row, row_number) -> str:
     """Generate email with improved error handling."""
     try:
         company = row[0] if len(row) > 0 else "Unknown Company"
@@ -151,7 +150,7 @@ async def generate_mail(row, row_number: int = 0) -> str:
         title = row[4] if len(row) > 4 else "Unknown Title"
         category = row[1] if len(row) > 1 else "Unknown Category"
         linkedin = row[5] if len(row) > 5 else ""
-        email = row[6] if len(row) > 6 else ""
+        email = row[1] if len(row) > 6 else ""
         business = row[2] if len(row) > 2 else "Unknown Business"
 
         question = f"""
@@ -177,7 +176,7 @@ async def generate_mail(row, row_number: int = 0) -> str:
         return f"Error: {str(e)}"
 
 
-async def process_emails(file_path: str) -> str | None:
+async def process_emails(file_path: str, row_number: int) -> str | None:
     email = ""
     """Process emails with better error handling and progress tracking."""
     try:
@@ -185,25 +184,24 @@ async def process_emails(file_path: str) -> str | None:
 
         with open(file_path, mode="r", encoding="latin-1") as file:
             csv_reader = csv.reader(file)
-            next(csv_reader)  # Skip the header row
+            next(csv_reader)
 
             processed = 0
             errors = 0
 
-            for row_number, row in enumerate(csv_reader, start=1):
+            for i, row in enumerate(csv_reader, start=1):
                 try:
-                    if len(row) < 7:  # Check if row has enough columns
+                    print(row)
+                    print(row_number)
+                    if len(row) < 6:  # Check if row has enough columns
                         print(f"Row {row_number}: Skipping - insufficient data")
                         continue
 
-                    result = await generate_mail(row, row_number)
+                    result = await generate_mail(row, 1)
                     email += f"Generated email:\n{result}"
                     print(email)
                     processed += 1
-
-                    # Progress indicator
-                    if processed % 5 == 0:
-                        print(f"Progress: {processed} emails processed")
+                    break
 
                 except Exception as e:
                     errors += 1
@@ -218,6 +216,6 @@ async def process_emails(file_path: str) -> str | None:
         print(f"Error in process_emails: {e}")
 
 
-async def start(file_name: str) -> str | None:
-    email = await process_emails(file_name)
+async def start(file_name: str, i) -> str | None:
+    email = await process_emails(file_name, i)
     return email
\ No newline at end of file
